==> indico-1.9.11.dev14-py2-none-any.whl: indico/testing/fixtures/person.py <==
# This file is part of Indico.
# Copyright (C) 2002 - 2017 European Organization for Nuclear Research (CERN).
#
# Indico is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 3 of the
# License, or (at your option) any later version.
#
# Indico is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Indico; if not, see <http://www.gnu.org/licenses/>.

from __future__ import unicode_literals

import pytest

from indico.modules.events.models.persons import EventPerson


@pytest.fixture
def create_event_person(db):
    def _create(event, user=None, first_name=None, last_name=None, email=None, affiliation=None, title=None):
        person = EventPerson(event_new=event,
                             user=user,
                             first_name=first_name or user.first_name,
                             last_name=last_name or user.last_name,
                             email=email or user.email,
                             affiliation=affiliation or user.affiliation,
                             title=title or user.title)
        db.session.add(person)
        db.session.flush()
        return person
    return _create

==> indico-2.0rc1-py2-none-any.whl: indico/testing/fixtures/person.py <==
# This file is part of Indico.
# Copyright (C) 2002 - 2017 European Organization for Nuclear Research (CERN).
#
# Indico is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 3 of the
# License, or (at your option) any later version.
#
# Indico is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Indico; if not, see <http://www.gnu.org/licenses/>.

from __future__ import unicode_literals

import pytest

from indico.modules.events.models.persons import EventPerson


@pytest.fixture
def create_event_person(db):
    def _create(event, user=None, first_name=None, last_name=None, email=None, affiliation=None, title=None):
        person = EventPerson(event=event,
                             user=user,
                             first_name=first_name or user.first_name,
                             last_name=last_name or user.last_name,
                             email=email or user.email,
                             affiliation=affiliation or user.affiliation,
                             title=title or user.title)
        db.session.add(person)
        db.session.flush()
        return person
    return _create
